"""Simple Python PAM

Note that for now, there is no nicer API for the C module. That doesn't
really limit you from doing anything, but you just wont have that nice an
API.
"""

from _spypam import *



#!/usr/bin/env python
from distutils.core import setup, Extension

setup(name="spypam", version="1.0", author="Ludvig Ericson",
    author_email="ludvig.ericson@gmail.com",
    ext_modules=[Extension("_spypam", ["spypammodule.c"], libraries=["pam"])],
    py_modules=["spypam"])
